@@ -41,11 +41,11 @@
  *****************************************************************************/
 
 #define PJ_LIB__
+
 #include "proj_internal.h"
 #include "projects.h"
-#include <stddef.h>
-#include <math.h>
-#include <errno.h>
+#include "proj_math.h"
+
 PROJ_HEAD(cart,    "Geodetic/cartesian conversions");
 
 
