@@ -43,8 +43,11 @@
 *
 ***********************************************************************/
 #define PJ_LIB__
+
 #include <errno.h>
-#include <proj.h>
+#include <math.h>
+
+#include "proj.h"
 #include "proj_internal.h"
 #include "projects.h"
 
@@ -311,4 +314,3 @@ PJ *TRANSFORMATION(molodensky,1) {
 
     return P;
 }
-
