@@ -64,9 +64,14 @@ Last update: 2017-05-16
 ***********************************************************************/
 
 #define PJ_LIB__
-#include <time.h>
+
 #include <errno.h>
+#include <math.h>
+#include <string.h>
+#include <time.h>
+
 #include "proj_internal.h"
+#include "proj_math.h"
 #include "projects.h"
 
 PROJ_HEAD(unitconvert, "Unit conversion");
@@ -75,7 +80,7 @@ typedef double (*tconvert)(double);
 
 struct TIME_UNITS {
     char        *id;        /* units keyword */
-    tconvert     t_in;      /* unit -> mod. julian date funtion pointer */
+    tconvert     t_in;      /* unit -> mod. julian date function pointer */
     tconvert     t_out;     /* mod. julian date > unit function pointer */
     char        *name;      /* comments */
 };
@@ -152,14 +157,14 @@ static double decimalyear_to_mjd(double decimalyear) {
 /***********************************************************************
     Epoch of modified julian date is 1858-11-16 00:00
 ************************************************************************/
-    int year;
+    long year;
     double fractional_year;
     double mjd;
 
     if( decimalyear < -10000 || decimalyear > 10000 )
         return 0;
 
-    year = (int)floor(decimalyear);
+    year = lround(floor(decimalyear));
     fractional_year = decimalyear - year;
     mjd = (year - 1859)*365 + 14 + 31;
     mjd += fractional_year*days_in_year(year);
@@ -228,9 +233,9 @@ static double yyyymmdd_to_mjd(double yyyymmdd) {
     Date given in YYYY-MM-DD format.
 ************************************************************************/
 
-    int year  = (int)floor( yyyymmdd / 10000 );
-    int month = (int)floor((yyyymmdd - year*10000) / 100);
-    int day   = (int)floor( yyyymmdd - year*10000 - month*100);
+    long year  = lround(floor( yyyymmdd / 10000 ));
+    long month = lround(floor((yyyymmdd - year*10000) / 100));
+    long day   = lround(floor( yyyymmdd - year*10000 - month*100));
     double mjd = daynumber_in_year(year, month, day);
 
     for (year -= 1; year > 1858; year--)
@@ -415,7 +420,7 @@ PJ *CONVERSION(unitconvert,0) {
             proj_log_debug(P, "xy_in unit: %s", pj_units[i].name);
         } else {
             if ( (f = pj_param (P->ctx, P->params, "dxy_in").f) == 0.0)
-                return pj_default_destructor(P, PJD_ERR_UNKNOW_UNIT_ID);
+                return pj_default_destructor(P, PJD_ERR_UNKNOWN_UNIT_ID);
         }
         if (f != 0.0)
             Q->xy_factor *= f;
@@ -429,7 +434,7 @@ PJ *CONVERSION(unitconvert,0) {
             proj_log_debug(P, "xy_out unit: %s", pj_units[i].name);
         } else {
             if ( (f = pj_param (P->ctx, P->params, "dxy_out").f) == 0.0)
-                return pj_default_destructor(P, PJD_ERR_UNKNOW_UNIT_ID);
+                return pj_default_destructor(P, PJD_ERR_UNKNOWN_UNIT_ID);
         }
         if (f != 0.0)
             Q->xy_factor /= f;
@@ -443,7 +448,7 @@ PJ *CONVERSION(unitconvert,0) {
             proj_log_debug(P, "z_in unit: %s", pj_units[i].name);
         } else {
             if ( (f = pj_param (P->ctx, P->params, "dz_in").f) == 0.0)
-                return pj_default_destructor(P, PJD_ERR_UNKNOW_UNIT_ID);
+                return pj_default_destructor(P, PJD_ERR_UNKNOWN_UNIT_ID);
         }
         if (f != 0.0)
             Q->z_factor *= f;
@@ -457,7 +462,7 @@ PJ *CONVERSION(unitconvert,0) {
             proj_log_debug(P, "z_out unit: %s", pj_units[i].name);
         } else {
             if ( (f = pj_param (P->ctx, P->params, "dz_out").f) == 0.0)
-                return pj_default_destructor(P, PJD_ERR_UNKNOW_UNIT_ID);
+                return pj_default_destructor(P, PJD_ERR_UNKNOWN_UNIT_ID);
         }
         if (f != 0.0)
             Q->z_factor /= f;
@@ -467,7 +472,7 @@ PJ *CONVERSION(unitconvert,0) {
     if ((name = pj_param (P->ctx, P->params, "st_in").s) != NULL) {
         for (i = 0; (s = time_units[i].id) && strcmp(name, s) ; ++i);
 
-        if (!s) return pj_default_destructor(P, PJD_ERR_UNKNOW_UNIT_ID); /* unknown unit conversion id */
+        if (!s) return pj_default_destructor(P, PJD_ERR_UNKNOWN_UNIT_ID); /* unknown unit conversion id */
 
         Q->t_in_id = i;
         proj_log_debug(P, "t_in unit: %s", time_units[i].name);
@@ -477,7 +482,7 @@ PJ *CONVERSION(unitconvert,0) {
     if ((name = pj_param (P->ctx, P->params, "st_out").s) != NULL) {
         for (i = 0; (s = time_units[i].id) && strcmp(name, s) ; ++i);
 
-        if (!s) return pj_default_destructor(P, PJD_ERR_UNKNOW_UNIT_ID); /* unknown unit conversion id */
+        if (!s) return pj_default_destructor(P, PJD_ERR_UNKNOWN_UNIT_ID); /* unknown unit conversion id */
 
         Q->t_out_id = i;
         proj_log_debug(P, "t_out unit: %s", time_units[i].name);
