@@ -24,7 +24,11 @@
  */
 
 #include "geodesic.h"
+#ifdef PJ_LIB__
+#include "proj_math.h"
+#else
 #include <math.h>
+#endif
 
 #if !defined(HAVE_C99_MATH)
 #define HAVE_C99_MATH 0
@@ -94,6 +98,7 @@ static void Init() {
     #else
     {
       real minus1 = -1;
+      /* cppcheck-suppress wrongmathcall */
       NaN = sqrt(minus1);
     }
     #endif
@@ -326,7 +331,7 @@ static real Lambda12(const struct geod_geodesic* g,
                      real* pssig1, real* pcsig1,
                      real* pssig2, real* pcsig2,
                      real* peps,
-                     real* pgomg12,
+                     real* pdomg12,
                      boolx diffp, real* pdlam12,
                      /* Scratch area of the right size */
                      real Ca[]);
@@ -476,10 +481,10 @@ void geod_lineinit(struct geod_geodesicline* l,
 void geod_gendirectline(struct geod_geodesicline* l,
                         const struct geod_geodesic* g,
                         real lat1, real lon1, real azi1,
-                        unsigned flags, real a12_s12,
+                        unsigned flags, real s12_a12,
                         unsigned caps) {
   geod_lineinit(l, g, lat1, lon1, azi1, caps);
-  geod_gensetdistance(l, flags, a12_s12);
+  geod_gensetdistance(l, flags, s12_a12);
 }
 
 void geod_directline(struct geod_geodesicline* l,
@@ -586,7 +591,7 @@ real geod_genposition(const struct geod_geodesicline* l,
   salp2 = l->salp0; calp2 = l->calp0 * csig2; /* No need to normalize */
 
   if (outmask & GEOD_DISTANCE)
-    s12 = flags & GEOD_ARCMODE ?
+    s12 = (flags & GEOD_ARCMODE) ?
       l->b * ((1 + l->A1m1) * sig12 + AB1) :
       s12_a12;
 
@@ -595,7 +600,7 @@ real geod_genposition(const struct geod_geodesicline* l,
     /* tan(omg2) = sin(alp0) * tan(sig2) */
     somg2 = l->salp0 * ssig2; comg2 = csig2;  /* No need to normalize */
     /* omg12 = omg2 - omg1 */
-    omg12 = flags & GEOD_LONG_UNROLL
+    omg12 = (flags & GEOD_LONG_UNROLL)
       ? E * (sig12
              - (atan2(    ssig2, csig2) - atan2(    l->ssig1, l->csig1))
              + (atan2(E * somg2, comg2) - atan2(E * l->somg1, l->comg1)))
@@ -605,7 +610,7 @@ real geod_genposition(const struct geod_geodesicline* l,
       ( sig12 + (SinCosSeries(TRUE, ssig2, csig2, l->C3a, nC3-1)
                  - l->B31));
     lon12 = lam12 / degree;
-    lon2 = flags & GEOD_LONG_UNROLL ? l->lon1 + lon12 :
+    lon2 = (flags & GEOD_LONG_UNROLL) ? l->lon1 + lon12 :
       AngNormalize(AngNormalize(l->lon1) + AngNormalize(lon12));
   }
 
@@ -668,22 +673,22 @@ real geod_genposition(const struct geod_geodesicline* l,
    */
   if ((outmask & GEOD_LATITUDE) && plat2)
     *plat2 = lat2;
-  if (outmask & GEOD_LONGITUDE)
+  if ((outmask & GEOD_LONGITUDE) && plon2)
     *plon2 = lon2;
-  if (outmask & GEOD_AZIMUTH)
+  if ((outmask & GEOD_AZIMUTH) && pazi2)
     *pazi2 = azi2;
-  if (outmask & GEOD_DISTANCE)
+  if ((outmask & GEOD_DISTANCE) && ps12)
     *ps12 = s12;
-  if (outmask & GEOD_REDUCEDLENGTH)
+  if ((outmask & GEOD_REDUCEDLENGTH) && pm12)
     *pm12 = m12;
   if (outmask & GEOD_GEODESICSCALE) {
     if (pM12) *pM12 = M12;
     if (pM21) *pM21 = M21;
   }
-  if (outmask & GEOD_AREA)
+  if ((outmask & GEOD_AREA) && pS12)
     *pS12 = S12;
 
-  return flags & GEOD_ARCMODE ? s12_a12 : sig12 / degree;
+  return (flags & GEOD_ARCMODE) ? s12_a12 : sig12 / degree;
 }
 
 void geod_setdistance(struct geod_geodesicline* l, real s13) {
@@ -698,7 +703,7 @@ static void geod_setarc(struct geod_geodesicline* l, real a13) {
 
 void geod_gensetdistance(struct geod_geodesicline* l,
  unsigned flags, real s13_a13) {
-  flags & GEOD_ARCMODE ?
+  (flags & GEOD_ARCMODE) ?
     geod_setarc(l, s13_a13) :
     geod_setdistance(l, s13_a13);
 }
@@ -727,7 +732,7 @@ real geod_gendirect(const struct geod_geodesic* g,
   geod_lineinit(&l, g, lat1, lon1, azi1,
                 /* Automatically supply GEOD_DISTANCE_IN if necessary */
                 outmask |
-                (flags & GEOD_ARCMODE ? GEOD_NONE : GEOD_DISTANCE_IN));
+                ((flags & GEOD_ARCMODE) ? GEOD_NONE : GEOD_DISTANCE_IN));
   return geod_genposition(&l, flags, s12_a12,
                           plat2, plon2, pazi2, ps12, pm12, pM12, pM21, pS12);
 }
@@ -854,8 +859,8 @@ static real geod_geninverse_int(const struct geod_geodesic* g,
                                   csig1 * csig2 + ssig1 * ssig2);
     Lengths(g, g->n, sig12, ssig1, csig1, dn1, ssig2, csig2, dn2,
             cbet1, cbet2, &s12x, &m12x, 0,
-            outmask & GEOD_GEODESICSCALE ? &M12 : 0,
-            outmask & GEOD_GEODESICSCALE ? &M21 : 0,
+            (outmask & GEOD_GEODESICSCALE) ? &M12 : 0,
+            (outmask & GEOD_GEODESICSCALE) ? &M21 : 0,
             Ca);
     /* Add the check for sig12 since zero length geodesics might yield m12 <
      * 0.  Test case was
@@ -978,8 +983,8 @@ static real geod_geninverse_int(const struct geod_geodesic* g,
       }
       Lengths(g, eps, sig12, ssig1, csig1, dn1, ssig2, csig2, dn2,
               cbet1, cbet2, &s12x, &m12x, 0,
-              outmask & GEOD_GEODESICSCALE ? &M12 : 0,
-              outmask & GEOD_GEODESICSCALE ? &M21 : 0, Ca);
+              (outmask & GEOD_GEODESICSCALE) ? &M12 : 0,
+              (outmask & GEOD_GEODESICSCALE) ? &M21 : 0, Ca);
       m12x *= g->b;
       s12x *= g->b;
       a12 = sig12 / degree;
