@@ -26,10 +26,16 @@
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
-#include <stddef.h>
+
 #include <errno.h>
-#include <proj.h>
+#include <stddef.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
+#include "proj.h"
 #include "proj_internal.h"
+#include "proj_math.h"
 #include "projects.h"
 #include "geodesic.h"
 
@@ -113,7 +119,7 @@ double proj_xyz_dist (PJ_COORD a, PJ_COORD b) {
 
 
 /* Measure numerical deviation after n roundtrips fwd-inv (or inv-fwd) */
-double proj_roundtrip (PJ *P, PJ_DIRECTION direction, int n, PJ_COORD *coo) {
+double proj_roundtrip (PJ *P, PJ_DIRECTION direction, int n, PJ_COORD *coord) {
     int i;
     PJ_COORD t, org;
 
@@ -126,9 +132,9 @@ double proj_roundtrip (PJ *P, PJ_DIRECTION direction, int n, PJ_COORD *coo) {
     }
 
     /* in the first half-step, we generate the output value */
-    org  = *coo;
-    *coo = proj_trans (P, direction, org);
-    t = *coo;
+    org  = *coord;
+    *coord = proj_trans (P, direction, org);
+    t = *coord;
 
     /* now we take n-1 full steps in inverse direction: We are */
     /* out of phase due to the half step already taken */
@@ -148,26 +154,26 @@ double proj_roundtrip (PJ *P, PJ_DIRECTION direction, int n, PJ_COORD *coo) {
 
 
 /**************************************************************************************/
-PJ_COORD proj_trans (PJ *P, PJ_DIRECTION direction, PJ_COORD coo) {
+PJ_COORD proj_trans (PJ *P, PJ_DIRECTION direction, PJ_COORD coord) {
 /***************************************************************************************
-Apply the transformation P to the coordinate coo, preferring the 4D interfaces if
+Apply the transformation P to the coordinate coord, preferring the 4D interfaces if
 available.
 
 See also pj_approx_2D_trans and pj_approx_3D_trans in pj_internal.c, which work
 similarly, but prefers the 2D resp. 3D interfaces if available.
 ***************************************************************************************/
     if (0==P)
-        return coo;
+        return coord;
     if (P->inverted)
         direction = -direction;
 
     switch (direction) {
         case PJ_FWD:
-            return pj_fwd4d (coo, P);
+            return pj_fwd4d (coord, P);
         case PJ_INV:
-            return  pj_inv4d (coo, P);
+            return  pj_inv4d (coord, P);
         case PJ_IDENT:
-            return coo;
+            return coord;
         default:
             break;
     }
@@ -357,7 +363,7 @@ size_t proj_trans_generic (
 
 
 /*************************************************************************************/
-PJ_COORD proj_geocentric_latitude (const PJ *P, PJ_DIRECTION direction, PJ_COORD coo) {
+PJ_COORD proj_geocentric_latitude (const PJ *P, PJ_DIRECTION direction, PJ_COORD coord) {
 /**************************************************************************************
     Convert geographical latitude to geocentric (or the other way round if
     direction = PJ_INV)
@@ -373,13 +379,13 @@ PJ_COORD proj_geocentric_latitude (const PJ *P, PJ_DIRECTION direction, PJ_COORD
     consequently, the input is copied directly to the output.
 **************************************************************************************/
     const double limit = M_HALFPI - 1e-9;
-    PJ_COORD res = coo;
-    if ((coo.lp.phi > limit) || (coo.lp.phi < -limit) || (P->es==0))
+    PJ_COORD res = coord;
+    if ((coord.lp.phi > limit) || (coord.lp.phi < -limit) || (P->es==0))
         return res;
     if (direction==PJ_FWD)
-        res.lp.phi = atan (P->one_es * tan (coo.lp.phi) );
+        res.lp.phi = atan (P->one_es * tan (coord.lp.phi) );
     else
-        res.lp.phi = atan (P->rone_es * tan (coo.lp.phi) );
+        res.lp.phi = atan (P->rone_es * tan (coord.lp.phi) );
 
     return res;
 }
@@ -409,7 +415,7 @@ in cs2cs compatibility mode.
 }
 
 /*************************************************************************************/
-static int pj_cs2cs_emulation_setup (PJ *P) {
+static int cs2cs_emulation_setup (PJ *P) {
 /**************************************************************************************
 If any cs2cs style modifiers are given (axis=..., towgs84=..., ) create the 4D API
 equivalent operations, so the preparation and finalization steps in the pj_inv/pj_fwd
@@ -419,6 +425,7 @@ Returns 1 on success, 0 on failure
 **************************************************************************************/
     PJ *Q;
     paralist *p;
+    int do_cart = 0;
     if (0==P)
         return 0;
 
@@ -481,8 +488,14 @@ Returns 1 on success, 0 on failure
         size_t n = strlen (s);
 
         /* We ignore null helmert shifts (common in auto-translated resource files, e.g. epsg) */
-        if (0==d[0] && 0==d[1] && 0==d[2] && 0==d[3] && 0==d[4] && 0==d[5] && 0==d[6])
+        if (0==d[0] && 0==d[1] && 0==d[2] && 0==d[3] && 0==d[4] && 0==d[5] && 0==d[6]) {
+            /* If the current ellipsoid is not WGS84, then make sure the */
+            /* change in ellipsoid is still done. */
+            if (!(fabs(P->a_orig - 6378137.0) < 1e-8 && fabs(P->es_orig - 0.0066943799901413) < 1e-15)) {
+                do_cart = 1;
+            }
             break;
+        }
 
         if (n <= 8) /* 8==strlen ("towgs84=") */
             return 0;
@@ -490,7 +503,7 @@ Returns 1 on success, 0 on failure
         def = malloc (100+n);
         if (0==def)
             return 0;
-        sprintf (def, "break_cs2cs_recursion     proj=helmert %s transpose", s);
+        sprintf (def, "break_cs2cs_recursion     proj=helmert exact %s transpose", s);
         Q = proj_create (P->ctx, def);
         pj_inherit_ellipsoid_def (P, Q);
         free (def);
@@ -503,9 +516,9 @@ Returns 1 on success, 0 on failure
 
     /* We also need cartesian/geographical transformations if we are working in */
     /* geocentric/cartesian space or we need to do a Helmert transform.         */
-    if (P->is_geocent || P->helmert) {
+    if (P->is_geocent || P->helmert || do_cart) {
         char def[150];
-        sprintf (def, "break_cs2cs_recursion     proj=cart   a=%40.20g  f=%40.20g", P->a, P->f);
+        sprintf (def, "break_cs2cs_recursion     proj=cart   a=%40.20g  es=%40.20g", P->a_orig, P->es_orig);
         Q = proj_create (P->ctx, def);
         if (0==Q)
             return 0;
@@ -564,7 +577,7 @@ PJ *proj_create (PJ_CONTEXT *ctx, const char *definition) {
     pj_dealloc (args);
 
     /* Support cs2cs-style modifiers */
-    ret = pj_cs2cs_emulation_setup  (P);
+    ret = cs2cs_emulation_setup  (P);
     if (0==ret)
         return proj_destroy (P);
 
@@ -632,14 +645,18 @@ PJ  *proj_create_crs_to_crs (PJ_CONTEXT *ctx, const char *srid_from, const char
 ******************************************************************************/
     PJ *P;
     char buffer[512];
+    size_t len;
 
     /* area not in use yet, suppressing warning */
     (void)area;
 
     strcpy(buffer, "+proj=pipeline +step +init=");
-    strncat(buffer, srid_from, 512-strlen(buffer));
-    strncat(buffer, " +inv +step +init=", 512-strlen(buffer));
-    strncat(buffer, srid_to, 512-strlen(buffer));
+    len = strlen(buffer);
+    strncat(buffer + len, srid_from, sizeof(buffer)-1-len);
+    len += strlen(buffer + len);
+    strncat(buffer + len, " +inv +step +init=", sizeof(buffer)-1-len);
+    len += strlen(buffer + len);
+    strncat(buffer + len, srid_to, sizeof(buffer)-1-len);
 
     P = proj_create(ctx, buffer);
 
@@ -1004,7 +1021,8 @@ PJ_INIT_INFO proj_init_info(const char *initname){
     key[64] = 0;
     strncat(key, ":metadata", 9);
     strcpy(param, "+init=");
-    strncat(param, key, 73);
+    /* The +strlen(param) avoids a cppcheck false positive warning */
+    strncat(param + strlen(param), key, sizeof(param)-1-strlen(param));
 
     start = pj_mkparam(param);
     pj_expand_init(ctx, start);
@@ -1036,7 +1054,7 @@ PJ_FACTORS proj_factors(PJ *P, PJ_COORD lp) {
     Characteristics include meridian, parallel and areal scales, angular
     distortion, meridian/parallel, meridian convergence and scale error.
 
-    returns PJ_FACTORS. If unsuccessfull, error number is set and the
+    returns PJ_FACTORS. If unsuccessful, error number is set and the
     struct returned contains NULL data.
 ******************************************************************************/
     PJ_FACTORS factors = {0,0,0,  0,0,0,  0,0,  0,0,0,0};
@@ -1067,4 +1085,3 @@ PJ_FACTORS proj_factors(PJ *P, PJ_COORD lp) {
 
     return factors;
 }
-
